@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, date
 import unittest
 import json
 
@@ -22,3 +22,10 @@ class TestRequests(unittest.TestCase):
         data = { 'created': datetime(2012, 3, 4, 5, 6, 7, 891011) }
         result = json.dumps(data, cls=DatetimeSerializer)
         self.assertEqual(result, '{"created": "2012-03-04T05:06:07.891011"}')
+
+    def test_date_serialization(self):
+        today = date.today()
+        data = {'created': today}
+        result = json.dumps(data, cls=DatetimeSerializer)
+        expected = '{"created": "%s"}' % today.isoformat()
+        self.assertEqual(result, expected)
